==> App-git_log_ch_usrdata-0.02.tar.gz: App-git_log_ch_usrdata-0.02/SECURITY.md <==
# Security Policy for the Software::Security::Policy distribution.

Report security issues by email to Klaus Rindfrey <klausrin@cpan.org>.

This is the Security Policy for Software::Security::Policy.

The latest version of the Security Policy can be found in the
[git repository for Software::Security::Policy](https://github.com/CPAN-Security/Software-Security-Policy/blob/main/SECURITY.md).

This text is based on the CPAN Security Group's Guidelines for Adding
a Security Policy to Perl Distributions (version 1.3.0)
https://security.metacpan.org/docs/guides/security-policy-for-authors.html

# How to Report a Security Vulnerability

Security vulnerabilities can be reported to the current Software::Security::Policy
maintainers by email to Klaus Rindfrey <k-rindfrey@gmx.de> <klausrin@cpan.org>.

Please include as many details as possible, including code samples
or test cases, so that we can reproduce the issue.  Check that your
report does not expose any sensitive data, such as passwords,
tokens, or personal information.

If you would like any help with triaging the issue, or if the issue
is being actively exploited, please copy the report to the CPAN
Security Group (CPANSec) at <cpan-security@security.metacpan.org>.

Please *do not* use the public issue reporting system on RT or
GitHub issues for reporting security vulnerabilities.

Please do not disclose the security vulnerability in public forums
until past any proposed date for public disclosure, or it has been
made public by the maintainers or CPANSec.  That includes patches or
pull requests.

For more information, see
[Report a Security Issue](https://security.metacpan.org/docs/report.html)
on the CPANSec website.

## Response to Reports

The maintainer(s) aim to acknowledge your security report as soon as
possible.  However, this project is maintained by a single person in
their spare time, and they cannot guarantee a rapid response.  If you
have not received a response from them within 7 days, then
please send a reminder to them and copy the report to CPANSec at
<cpan-security@security.metacpan.org>.

Please note that the initial response to your report will be an
acknowledgement, with a possible query for more information.  It
will not necessarily include any fixes for the issue.

The project maintainer(s) may forward this issue to the security
contacts for other projects where we believe it is relevant.  This
may include embedded libraries, system libraries, prerequisite
modules or downstream software that uses this software.

They may also forward this issue to CPANSec.

# Which Software This Policy Applies To

Any security vulnerabilities in Software::Security::Policy are covered by this policy.

Security vulnerabilities in versions of any libraries that are
included in Software::Security::Policy are also covered by this policy.

Security vulnerabilities are considered anything that allows users
to execute unauthorised code, access unauthorised resources, or to
have an adverse impact on accessibility or performance of a system.

Security vulnerabilities in upstream software (prerequisite modules
or system libraries, or in Perl), are not covered by this policy
unless they affect Software::Security::Policy, or Software::Security::Policy can
be used to exploit vulnerabilities in them.

Security vulnerabilities in downstream software (any software that
uses Software::Security::Policy, or plugins to it that are not included with the
Software::Security::Policy distribution) are not covered by this policy.

## Supported Versions of Software::Security::Policy

The maintainer(s) will only commit to releasing security fixes for
the latest version of Software::Security::Policy.

Note that the Software::Security::Policy project only supports major versions of Perl
released in the past 10 years, even though Software::Security::Policy will run on
older versions of Perl.  If a security fix requires us to increase
the minimum version of Perl that is supported, then we may do so.

# Installation and Usage Issues

The distribution metadata specifies minimum versions of
prerequisites that are required for Software::Security::Policy to work.  However, some
of these prerequisites may have security vulnerabilities, and you
should ensure that you are using up-to-date versions of these
prerequisites.

Where security vulnerabilities are known, the metadata may indicate
newer versions as recommended.

## Usage

Please see the software documentation for further information.

==> App-git_log_ch_usrdata-0.03.tar.gz: App-git_log_ch_usrdata-0.03/SECURITY.md <==
# Security Policy for the App::git_log_ch_usrdata distribution.

Report security issues by email to Klaus Rindfrey <klausrin@cpan.org>.

This is the Security Policy for App::git_log_ch_usrdata.

The latest version of the Security Policy can be found in the
[git repository for App::git_log_ch_usrdata](https://github.com/klaus-rindfrey/perl-app-git_log_ch_usrdata/blob/main/SECURITY.md).

This text is based on the CPAN Security Group's Guidelines for Adding
a Security Policy to Perl Distributions (version 1.3.0)
https://security.metacpan.org/docs/guides/security-policy-for-authors.html

# How to Report a Security Vulnerability

Security vulnerabilities can be reported to the current App::git_log_ch_usrdata
maintainers by email to Klaus Rindfrey <klausrin@cpan.org>.

Please include as many details as possible, including code samples
or test cases, so that we can reproduce the issue.  Check that your
report does not expose any sensitive data, such as passwords,
tokens, or personal information.

If you would like any help with triaging the issue, or if the issue
is being actively exploited, please copy the report to the CPAN
Security Group (CPANSec) at <cpan-security@security.metacpan.org>.

Please *do not* use the public issue reporting system on RT or
GitHub issues for reporting security vulnerabilities.

Please do not disclose the security vulnerability in public forums
until past any proposed date for public disclosure, or it has been
made public by the maintainers or CPANSec.  That includes patches or
pull requests.

For more information, see
[Report a Security Issue](https://security.metacpan.org/docs/report.html)
on the CPANSec website.

## Response to Reports

The maintainer(s) aim to acknowledge your security report as soon as
possible.  However, this project is maintained by a single person in
their spare time, and they cannot guarantee a rapid response.  If you
have not received a response from them within 10 days, then
please send a reminder to them and copy the report to CPANSec at
<cpan-security@security.metacpan.org>.

Please note that the initial response to your report will be an
acknowledgement, with a possible query for more information.  It
will not necessarily include any fixes for the issue.

The project maintainer(s) may forward this issue to the security
contacts for other projects where we believe it is relevant.  This
may include embedded libraries, system libraries, prerequisite
modules or downstream software that uses this software.

They may also forward this issue to CPANSec.

# Which Software This Policy Applies To

Any security vulnerabilities in App::git_log_ch_usrdata are covered by this policy.

Security vulnerabilities in versions of any libraries that are
included in App::git_log_ch_usrdata are also covered by this policy.

Security vulnerabilities are considered anything that allows users
to execute unauthorised code, access unauthorised resources, or to
have an adverse impact on accessibility or performance of a system.

Security vulnerabilities in upstream software (prerequisite modules
or system libraries, or in Perl), are not covered by this policy
unless they affect App::git_log_ch_usrdata, or App::git_log_ch_usrdata can
be used to exploit vulnerabilities in them.

Security vulnerabilities in downstream software (any software that
uses App::git_log_ch_usrdata, or plugins to it that are not included with the
App::git_log_ch_usrdata distribution) are not covered by this policy.

## Supported Versions of App::git_log_ch_usrdata

The maintainer(s) will only commit to releasing security fixes for
the latest version of App::git_log_ch_usrdata.

Note that the App::git_log_ch_usrdata project only supports major versions of Perl
released in the past 10 years, even though App::git_log_ch_usrdata will run on
older versions of Perl.  If a security fix requires us to increase
the minimum version of Perl that is supported, then we may do so.

# Installation and Usage Issues

The distribution metadata specifies minimum versions of
prerequisites that are required for App::git_log_ch_usrdata to work.  However, some
of these prerequisites may have security vulnerabilities, and you
should ensure that you are using up-to-date versions of these
prerequisites.

Where security vulnerabilities are known, the metadata may indicate
newer versions as recommended.

## Usage

Please see the software documentation for further information.
